<?php
/* ======================================================
 # Support Hours for Joomla! - v1.6.2 (free version)
 # -------------------------------------------------------
 # For Joomla! CMS (v4.x)
 # Author: Web357 (Yiannis Christodoulou)
 # Copyright (©) 2014-2023 Web357. All rights reserved.
 # License: GNU/GPLv3, http://www.gnu.org/licenses/gpl-3.0.html
 # Website: https:/www.web357.com
 # Demo: https://demo.web357.com/joomla/browse/support-hours
 # Support: support@web357.com
 # Last modified: Monday 10 July 2023, 03:51:28 AM
 ========================================================= */
defined('_JEXEC') or die;

class modSupportHoursHelper
{
	function getDate($Y, $m, $d, $dateformat, $days, $day_of_the_week, $day, $months, $month, $short_month, $full_month, $year, $output_type = 'print')
	{
		// Build Date
		$default_date = $Y."-".$m."-".$d;
		
		if ($output_type == 'print'):
			
			if (!empty($dateformat))
			{
				if ($dateformat == 'l')
				{
					$print_date = JText::_('MOD_SUPPORTHOURS_'.strtoupper(date($dateformat, strtotime($default_date)))); // Wednesday > WEDNESDAY
				}
				elseif ($dateformat == 'D')
				{
					$print_date = JText::_('MOD_SUPPORTHOURS_'.strtoupper(date($dateformat, strtotime($default_date)))); // Wed = WED
				}
				else
				{
					$print_date = date($dateformat, strtotime($default_date));
				}
			}
			else
			{
				$print_date = '';
			}

		elseif ($output_type == 'value'):
			//$print_date = (!empty($dateformat)) ? date($dateformat, strtotime($default_date)) : date('Y-m-d', strtotime($default_date));
			$print_date = date('Y-m-d', strtotime($default_date));
		endif;
		
		// Date format
		switch ($dateformat):

			// Full Date Format
			case "dddd, d mmmm yyyyy":
				$date = $days[$day_of_the_week].", ".$day." ".$months[$month - 1]." ".$year;
			break;
			case "dddd, dd mmmm yyyyy":
				$date = $days[$day_of_the_week].", ".$d." ".$months[$month - 1]." ".$year;
			break;
			case "dddd, d mmm yyyyy":
				$date = $days[$day_of_the_week].", ".$day." ".$short_month." ".$year;
			break;
			case "dddd, dd mmm yyyyy":
				$date = $days[$day_of_the_week].", ".$d." ".$short_month." ".$year;
			break;
			case "dddd, dd-mm-yyyyy":
				$date = $days[$day_of_the_week].", ".$d."-".$m."-".$year;
			break;
			
			// Month Day, Year
			case "mmmm dd, yyyy":
				$date = $full_month." ".$d.", ".$year;
			break;
			case "mmmm d, yyyy":
				$date = $full_month." ".$day.", ".$year;
			break;
			case "mmm dd, yyyy":
				$date = $short_month." ".$d.", ".$year;
			break;
			case "mmm d, yyyy":
				$date = $short_month." ".$day.", ".$year;
			break;
		
			// Day Month, Year
			case "dd mmmm, yyyy":
				$date = $d." ".$full_month.", ".$year;
			break;
			case "d mmmm, yyyy":
				$date = $day." ".$full_month.", ".$year;
			break;
			case "dd mmm, yyyy":
				$date = $d." ".$short_month.", ".$year;
			break;
			case "d mmm, yyyy":
				$date = $day." ".$short_month.", ".$year;
			break;
			
			// Default
			default:
				$date = $print_date;
		endswitch;

		return $date;
	}

	function getTime($type = 'our_time', $timeformat, $display_pm_am, $hour_system, $offset, $h, $i, $a, $module)
	{
		$html = '';
		
		if (!empty($offset)):
			// our time
			// calculate timezone
			$tz = new DateTimeZone($offset);
			$date = new DateTime('now', $tz);
			$offset = $tz->getOffset($date) . ' seconds';
			$tzoffset = ((int) $offset > 0 ? (int) $offset / 3600 : 0); // example: -4, -4
			$dateOffset = clone $date;
			$dateOffset->sub(DateInterval::createFromDateString($offset));
			$interval = $dateOffset->diff($date);
			$offset_sign = $interval->format('%R');
			$offset_hours = $interval->format('%H');
			$offset_minutes = $interval->format('%I');
		else:
			// visitor's time
			$offset_sign = '+';
			$offset_hours = 0;
			$offset_minutes = 0;
		endif;
		
		$js_time_a = '
		<span id="mod_supporthours_'.$type.'_'.$module->id.'" class="mod_sh_pmam"></span>
		<script type="text/javascript">
			<!--
			zone=0
			isitlocal=true;
			ampm="";
			
			function mod_supporthours_'.$type.'_'.$module->id.'()
			{
				now=new Date();
				'.(!empty($offset) ? 'ofst="'.$offset_hours.'"' /* custom time */ : 'ofst=now.getTimezoneOffset()' /* users time */ ).'; 
				'.(!empty($offset) ? 'ofst_minutes="'.$offset_minutes.'";' : '').'
				'.(!empty($offset) ? 'ofst_sign="'.$offset_sign.'";' : '').'
				'.(!empty($offset) ? 'now.setUTCHours(now.getUTCHours()'.$offset_sign.'Math.abs(ofst), now.getUTCMinutes()'.$offset_sign.'Math.abs(ofst_minutes));' : 'now.setUTCHours(now.getUTCHours()+Math.abs(ofst), now.getUTCMinutes()+Math.abs(ofst));').'
				timezone = now.getTimezoneOffset();
				secs=now.getUTCSeconds();
				sec=-1.57+Math.PI*secs/30;
				mins=now.getUTCMinutes();
				min=-1.57+Math.PI*mins/30;
				hr=(isitlocal)? now.getUTCHours():(now.getUTCHours() + parseInt(ofst)) + parseInt(zone);
				hrs=-1.575+Math.PI*hr/6+Math.PI*parseInt(now.getMinutes())/360;
				if (hr < 0) hr+=24;
				if (hr > 23) hr-=24;
				'.(($display_pm_am) ? '
				ampm = (hr > 11) ? "'.JText::_("MOD_SUPPORTHOURS_PM").'" : "'.JText::_("MOD_SUPPORTHOURS_AM").'"; 
				' : '
				ampm = (hr > 11)?"":"";
				').'
				statusampm = ampm;
												
				hr2 = hr;
				if (hr2 == 0) hr2='.$hour_system.';//24 or 12
				(hr2 < 13)?hr2:hr2 %= '.$hour_system.';// 24 or 12
				if (hr2<10) hr2=""+hr2'."\n";

		$js_visitor_time_a = '
			<!--
			zone=0
			isitlocal=true;
			ampm="";
			
			function mod_supporthours_'.$type.'_'.$module->id.'()
			{
				now=new Date();
				'.(!empty($offset) ? 'ofst="'.$offset_hours.'"' /* custom time */ : 'ofst=now.getTimezoneOffset()' /* users time */ ).'; 
				'.(!empty($offset) ? 'ofst_minutes="'.$offset_minutes.'";' : '').'
				'.(!empty($offset) ? 'ofst_sign="'.$offset_sign.'";' : '').'
				timezone = now.getTimezoneOffset();
				secs=now.getSeconds();
				sec=-1.57+Math.PI*secs/30;
				mins=now.getMinutes();
				min=-1.57+Math.PI*mins/30;
				hr=(isitlocal)? now.getHours():(now.getHours() + parseInt(ofst)) + parseInt(zone);
				hrs=-1.575+Math.PI*hr/6+Math.PI*parseInt(now.getMinutes())/360;
				if (hr < 0) hr+=24;
				if (hr > 23) hr-=24;
				'.(($display_pm_am) ? '
				ampm = (hr > 11) ? "'.JText::_("MOD_SUPPORTHOURS_PM").'" : "'.JText::_("MOD_SUPPORTHOURS_AM").'"; 
				' : '
				ampm = (hr > 11)?"":"";
				').'
				statusampm = ampm;
												
				hr2 = hr;
				if (hr2 == 0) hr2='.$hour_system.';//24 or 12
				(hr2 < 13)?hr2:hr2 %= '.$hour_system.';// 24 or 12
				if (hr2<10) hr2=""+hr2'."\n";			
			
		$js_time_b = '	
				document.getElementById("mod_supporthours_'.$type.'_'.$module->id.'").innerHTML=finaltime
				setTimeout("mod_supporthours_'.$type.'_'.$module->id.'()",1000)
			}
			mod_supporthours_'.$type.'_'.$module->id.'()
			//-->
		</script>';
		
		$js_visitor_time_b = '	
				document.getElementById("mod_supporthours_'.$type.'_'.$module->id.'").innerHTML=finaltime
				setTimeout("mod_supporthours_'.$type.'_'.$module->id.'()",1000)
			}
			mod_supporthours_'.$type.'_'.$module->id.'()
			//-->';
		
		if ($type == 'our_time_static'):
			return $h.":".$i.($hour_system == '12' ? " ".JText::_('MOD_SUPPORTHOURS_'.$a) : '');
		
		elseif ($type == 'visitor_time_static' || $type == 'visitor_time_display'):

			// to ajax/flashing
			$html .= '<span id="mod_supporthours_'.$type.'_'.$module->id.'" class="mod_sh_pmam"></span>';
			$html .= '<script type="text/javascript">';
			$html .= ($type == 'visitor_time_display') ? $js_visitor_time_a : '';
			
			if ($type == 'visitor_time_static'):
				$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+""+statusampm;'."\n";
			elseif ($type == 'visitor_time_display'):
				
				// Time format
				switch ($timeformat) :
					
					case 1: // 19:32 (static)			
						$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+""+statusampm;'."\n";
					break;
					
					case 2: // 19:32 (ajax/flashing)
						$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+""+statusampm;'."\n";
					break;	
		
					case 3: // 19:32:22 (ajax/flashing)
						$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+":"+((secs < 10)?"0"+secs:secs)+""+statusampm;'."\n";
					break;
					
					case 4: // none
						$html .= "";
					break;
					
				endswitch;
				
			endif;

			$html .= ($type == 'visitor_time_display') ? $js_visitor_time_b : '';
			
			$html .= '</script>';
	
			$session = JFactory::getSession();
			$visitor_time_static = $session->get('visitor_time_static'); // for the range

			if ($type == 'visitor_time_static'):
				return $visitor_time_static;
			elseif ($type == 'visitor_time_display'):
				return $html;
			endif;
		
		else:

			// Time format
			switch ($timeformat) :
				
				case 1: // 19:32 (static)			
					$html .= " ".$h.":".$i;
					$html .= ($display_pm_am) ? "".JText::_('MOD_SUPPORTHOURS_'.$a) : '';
				break;
				
				case 2: // 19:32 (ajax/flashing)
					$html .= $js_time_a;
					$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+""+statusampm;'."\n";
					$html .= $js_time_b;
				break;	
	
				case 3: // 19:32:22 (ajax/flashing)
					$html .= $js_time_a;
					$html .= 'var finaltime=hr2+":"+((mins < 10)?"0"+mins:mins)+":"+((secs < 10)?"0"+secs:secs)+""+statusampm;'."\n";
					$html .= $js_time_b;
				break;
				
				case 4: // none
					$html .= "";
				break;
				
			endswitch;

			return $html;
		endif;
		
	}
	
	function check_in_range($start_date, $end_date, $date_from_user)
	{
		if (empty($start_date) || empty($end_date)):
			return false;
		endif;

		// Convert to timestamp
		$start_ts = strtotime($start_date);
		$end_ts = strtotime($end_date);
		$user_ts = strtotime($date_from_user);

		if ($end_date === '0:00')
		{
			$end_ts = strtotime(date("H:i:s", strtotime("23:59:59")));
		}

		// Check that user date is between start & end
		return (($user_ts >= $start_ts) && ($user_ts <= $end_ts));
	}
}